@@ -195,11 +195,13 @@ def plotly_wordcloud(token_count_dic: dict) -> plotly.graph_objects.Scatter:
         x.append(i[0])
         y.append(i[1])
 
-    # get the relative occurence frequencies
+    # get the relative occurrence frequencies
     new_freq_list = []
     for i in rel_freq_list:
-        new_freq_list.append(i * 100)
-    new_freq_list
+        i_cast = round(i,3)
+        i_cast *= 100
+        i_cast = float(i_cast)
+        new_freq_list.append(i_cast)
 
     trace = go.Scatter(
         x=x,
@@ -412,7 +414,7 @@ def generate_report(
             else:
                 items_dic[t] = 1
 
-    def get_pos(tagged_tokens: List[Tuple(str, str)], goal_pos: str) -> List:
+    def get_pos(tagged_tokens: List[Tuple[str, str]], goal_pos: str) -> List:
         """Extracts goal_pos POS tags from tagged_tokens.
 
         Args:
